@@ -4,9 +4,9 @@
 package clusterapply
 
 import (
-	ctlconf "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/config"
-	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
-	ctlresm "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resourcesmisc"
+	ctlconf "carvel.dev/kapp/pkg/kapp/config"
+	ctlres "carvel.dev/kapp/pkg/kapp/resources"
+	ctlresm "carvel.dev/kapp/pkg/kapp/resourcesmisc"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 )
 
