@@ -6,7 +6,7 @@ package permissions
 import (
 	"context"
 
-	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
+	ctlres "carvel.dev/kapp/pkg/kapp/resources"
 	authv1 "k8s.io/api/authorization/v1"
 	"k8s.io/apimachinery/pkg/api/meta"
 	authv1client "k8s.io/client-go/kubernetes/typed/authorization/v1"
