@@ -6,8 +6,8 @@ package resourcesmisc
 import (
 	"fmt"
 
-	ctlconf "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/config"
-	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
+	ctlconf "carvel.dev/kapp/pkg/kapp/config"
+	ctlres "carvel.dev/kapp/pkg/kapp/resources"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
