@@ -6,7 +6,7 @@ package resourcesmisc
 import (
 	"fmt"
 
-	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
+	ctlres "carvel.dev/kapp/pkg/kapp/resources"
 	appsv1 "k8s.io/api/apps/v1"
 )
 
